@@ -53,7 +53,7 @@ resizer.refreshDebugDiv = function ()
 }
 
 
-$(function ()
+$(window).load(function ()
 {
     resizer.run();
     $(window).resize(function() {
